import os
import random
import string

DATA_PATH = '/home/mark/Projects/glyph-generator/data'
INPUT_PATH = f'{DATA_PATH}/input/glyphs-unclassified/'
FILE_PREFIX = 'G-'
FILE_SUFFIX = '-F.jpg'
FILE_MASK = 'DDDDD'  # File name structure: D = digit, L = letter

def generate_random_name(mask: str, prefix: str, suffix: str, existing_names: set) -> str:
    """Generate a unique random file name based on the given mask."""
    while True:
        random_name = ''.join(
            random.choice(string.digits) if char == 'D' else random.choice(string.ascii_lowercase) for char in mask
        )
        full_name = f'{prefix}{random_name}{suffix}'
        if full_name not in existing_names:
            return full_name

def rename_files_in_directory(input_dir: str, file_prefix: str, file_suffix: str, file_mask: str):
    """Rename all files in the given directory randomly based on the mask."""
    existing_names = set(os.listdir(input_dir))

    for file_name in os.listdir(input_dir):
        file_path = os.path.join(input_dir, file_name)
        if os.path.isfile(file_path):
            new_name = generate_random_name(file_mask, file_prefix, file_suffix, existing_names)
            new_path = os.path.join(input_dir, new_name)
            os.rename(file_path, new_path)
            print(f'Renamed: {file_name} -> {new_name}')
            existing_names.add(new_name)

# Run the renaming process
rename_files_in_directory(INPUT_PATH, FILE_PREFIX, FILE_SUFFIX, FILE_MASK)
